.. _staticmask:

****************
Static Mask Step
****************
This step focuses entirely on creating a static mask for each detector
used in the input images of all negative (presumably bad) pixel values.

.. moduleauthor:: Warren Hack <help@stsci.edu>

.. automodule:: drizzlepac.staticMask
   :members:
   :undoc-members:
